==> POCSdk-1.0.159-sources.jar: com/xdja/poc/sdk/db/DBConstant.java <==
package com.xdja.poc.sdk.db;

/**
 * POC-Sdk
 * 功能
 * 描述
 * created by Wwq : 2018/11/6
 */

@SuppressWarnings("CanBeFinal")
public class DBConstant {
    public static String CHANNEL_TABLE = "Channel";//表名称
    public static String KEY = "key";//表主键
    public static String USERID = "userId";//用户id
    public static String OWNERID = "ownerId";//频道创建者的ID
    public static String ACTIVEUSERID = "activeUserId";
    public static String ROOMID = "roomId";//频道id
    public static String ROOMNAME = "roomName";//频道名称
    public static String MEMEBERIDS = "memeberIds";//频道成员信息
    public static String ONLINECOUNT = "onLineCount";//在线频道数
    public static String ISSILENCE = "isSilence";//是否静音
    public static String SPEAKERUSERID = "speakerUserId";//当前讲话人的id
    public static String SPEAKERUSERNAME = "speakerUserName";//当前讲话人的名称
    public static String STATUS = "status";
    public static String ISTOPSTICK = "isTopStick";
    public static String TOPSTICKINDEX = "topStickIndex";
    public static String TOPSTICKTIME = "topStickTime";
    public static String GROUPTYPE = "groupType";
    public static String USERNAMES = "userNames";
    public static String ISPTTKEY = "isPttKey";//表是否有ptt属性
    public static String CHANNELPWD = "channelPwd";//频道口令
    public static String CHANNELPWDMODE = "channelPwdMode";//口令模式
    public static String MAXINVITEMEMBERSCOUNT = "maxInviteMembersCount";//频道最大成员数

    public static String CREATETIME = "createTime";//创建时间

    public static String TABLE_SQL = "create table " + CHANNEL_TABLE + "(" +
            "_id" + " integer primary key," +
            KEY + " text ," +
            USERID + " text ," +
            OWNERID + " text ," +
            ACTIVEUSERID + " text ," +
            ROOMID + " text ," +
            ROOMNAME + " text ," +
            MEMEBERIDS + " text ," +
            ONLINECOUNT + " INTEGER DEFAULT 0," +
            ISSILENCE + " INTEGER DEFAULT 0," +
            SPEAKERUSERID + " text," +
            SPEAKERUSERNAME + " text," +
            STATUS + " INTEGER DEFAULT 0," +
            ISTOPSTICK + " INTEGER DEFAULT 0," +
            TOPSTICKINDEX + " INTEGER DEFAULT 0," +
            TOPSTICKTIME + " text," +
            GROUPTYPE + " text," +
            USERNAMES + " text," +
            ISPTTKEY + " INTEGER DEFAULT 0," +
            CHANNELPWD + " INTEGER DEFAULT 0," +
            MAXINVITEMEMBERSCOUNT + " INTEGER DEFAULT 0," +
            CHANNELPWDMODE + " text," +
            CREATETIME + " text"+
            ")";
}

==> POCSdk-1.0.202-sources.jar: com/xdja/poc/sdk/db/DBConstant.java <==
package com.xdja.poc.sdk.db;

/**
 * POC-Sdk
 * 功能
 * 描述
 * created by Wwq : 2018/11/6
 */

@SuppressWarnings("CanBeFinal")
public class DBConstant {
    public static String CHANNEL_TABLE = "Channel";//表名称
    public static String KEY = "key";//表主键
    public static String USERID = "userId";//用户id
    public static String OWNERID = "ownerId";//频道创建者的ID
    public static String ACTIVEUSERID = "activeUserId";
    public static String ROOMID = "roomId";//频道id
    public static String ROOMNAME = "roomName";//频道名称
    public static String MEMEBERIDS = "memeberIds";//频道成员信息
    public static String ONLINECOUNT = "onLineCount";//在线频道数
    public static String ISSILENCE = "isSilence";//是否静音
    public static String SPEAKERUSERID = "speakerUserId";//当前讲话人的id
    public static String SPEAKERUSERNAME = "speakerUserName";//当前讲话人的名称
    public static String STATUS = "status";
    public static String ISTOPSTICK = "isTopStick";
    public static String TOPSTICKINDEX = "topStickIndex";
    public static String TOPSTICKTIME = "topStickTime";
    public static String GROUPTYPE = "groupType";
    public static String USERNAMES = "userNames";
    public static String ISPTTKEY = "isPttKey";//表是否有ptt属性
    public static String CHANNELPWD = "channelPwd";//频道口令
    public static String CHANNELPWDMODE = "channelPwdMode";//口令模式
    public static String MAXINVITEMEMBERSCOUNT = "maxInviteMembersCount";//频道最大成员数

    public static String CREATETIME = "createTime";//创建时间

    public static String TABLE_SQL = "create table if not exists " + CHANNEL_TABLE + "(" +
            "_id" + " integer primary key," +
            KEY + " text ," +
            USERID + " text ," +
            OWNERID + " text ," +
            ACTIVEUSERID + " text ," +
            ROOMID + " text ," +
            ROOMNAME + " text ," +
            MEMEBERIDS + " text ," +
            ONLINECOUNT + " INTEGER DEFAULT 0," +
            ISSILENCE + " INTEGER DEFAULT 0," +
            SPEAKERUSERID + " text," +
            SPEAKERUSERNAME + " text," +
            STATUS + " INTEGER DEFAULT 0," +
            ISTOPSTICK + " INTEGER DEFAULT 0," +
            TOPSTICKINDEX + " INTEGER DEFAULT 0," +
            TOPSTICKTIME + " text," +
            GROUPTYPE + " text," +
            USERNAMES + " text," +
            ISPTTKEY + " INTEGER DEFAULT 0," +
            CHANNELPWD + " INTEGER DEFAULT 0," +
            MAXINVITEMEMBERSCOUNT + " INTEGER DEFAULT 0," +
            CHANNELPWDMODE + " text," +
            CREATETIME + " text"+
            ")";
}
